@@ -42,7 +42,7 @@ from paramiko.pkey import (
     load_private_key,
     load_private_key_file,
 )
-from paramiko.py3compat import StringIO, byte_chr, b, PY2
+from paramiko.py3compat import StringIO, byte_chr, b
 
 from .util import _support
 
@@ -141,9 +141,6 @@ INVALID/PADDING
 
 x1234 = b'\x01\x02\x03\x04'
 
-TEST_KEY_BYTESTR_2 = '\x00\x00\x00\x07ssh-rsa\x00\x00\x00\x01#\x00\x00\x00\x81\x00\xd3\x8fV\xea\x07\x85\xa6k%\x8d<\x1f\xbc\x8dT\x98\xa5\x96$\xf3E#\xbe>\xbc\xd2\x93\x93\x87f\xceD\x18\xdb \x0c\xb3\xa1a\x96\xf8e#\xcc\xacS\x8a#\xefVlE\x83\x1epv\xc1o\x17M\xef\xdf\x89DUXL\xa6\x8b\xaa<\x06\x10\xd7\x93w\xec\xaf\xe2\xaf\x95\xd8\xfb\xd9\xbfw\xcb\x9f0)#y{\x10\x90\xaa\x85l\tPru\x8c\t\x19\xce\xa0\xf1\xd2\xdc\x8e/\x8b\xa8f\x9c0\xdey\x84\xd2F\xf7\xcbmm\x1f\x87'  # noqa: E501
-TEST_KEY_BYTESTR_3 = '\x00\x00\x00\x07ssh-rsa\x00\x00\x00\x01#\x00\x00\x00\x00ӏV\x07k%<\x1fT$E#>ғfD\x18 \x0cae#̬S#VlE\x1epvo\x17M߉DUXL<\x06\x10דw\u2bd5ٿw˟0)#y{\x10l\tPru\t\x19Π\u070e/f0yFmm\x1f'  # noqa: E501
-
 
 class KeyTest(unittest.TestCase):
 
@@ -186,6 +183,9 @@ class KeyTest(unittest.TestCase):
         key2 = RSAKey.from_private_key(s)
         self.assertEqual(key, key2)
 
+        # ensure comparison does not raise exception
+        assert key != None  # noqa: E711
+
     def test_load_rsa_password(self):
         key = RSAKey.from_private_key_file(_support('test_rsa_password.key'), 'television')
         self.assertEqual('ssh-rsa', key.get_name())
@@ -211,6 +211,9 @@ class KeyTest(unittest.TestCase):
         key2 = DSSKey.from_private_key(s)
         self.assertEqual(key, key2)
 
+        # ensure comparison does not raise exception
+        assert key != None  # noqa: E711
+
     def test_load_dss_password(self):
         key = DSSKey.from_private_key_file(_support('test_dss_password.key'), 'television')
         self.assertEqual('ssh-dss', key.get_name())
@@ -323,6 +326,9 @@ class KeyTest(unittest.TestCase):
         key2 = ECDSAKey.from_private_key(s)
         self.assertEqual(key, key2)
 
+        # ensure comparison does not raise exception
+        assert key != None  # noqa: E711
+
     def test_load_ecdsa_password_256(self):
         key = ECDSAKey.from_private_key_file(_support('test_ecdsa_password_256.key'),
                                              b'television')
@@ -517,11 +523,6 @@ class KeyTest(unittest.TestCase):
         finally:
             os.remove(newfile)
 
-    def test_stringification(self):
-        key = RSAKey.from_private_key_file(_support('test_rsa.key'))
-        comparable = TEST_KEY_BYTESTR_2 if PY2 else TEST_KEY_BYTESTR_3
-        self.assertEqual(str(key), comparable)
-
     @pytest.mark.skipif("not Ed25519Key.is_supported()")
     def test_ed25519(self):
         key1 = Ed25519Key.from_private_key_file(_support('test_ed25519.key'))
@@ -530,6 +531,9 @@ class KeyTest(unittest.TestCase):
         )
         self.assertNotEqual(key1.asbytes(), key2.asbytes())
 
+        # ensure comparison does not raise exception
+        assert key1 != None  # noqa: E711
+
     @pytest.mark.skipif("not Ed25519Key.is_supported()")
     def test_ed25519_nopad(self):
         Ed25519Key.from_private_key_file(_support("test_ed25519_nopad.key"))
@@ -612,6 +616,25 @@ class KeyTest(unittest.TestCase):
             _support('test_rsa.key-cert.pub'),
         )
 
+    def keys_loaded_twice(self):
+        for key_class, filename in [
+            (RSAKey, "test_rsa.key"),
+            (DSSKey, "test_dss.key"),
+            (ECDSAKey, "test_ecdsa_256.key"),
+            (Ed25519Key, "test_ed25519.key"),
+        ]:
+            key1 = key_class.from_private_key_file(_support(filename))
+            key2 = key_class.from_private_key_file(_support(filename))
+            yield key1, key2
+
+    def test_keys_are_comparable(self):
+        for key1, key2 in self.keys_loaded_twice():
+            assert key1 == key2
+
+    def test_keys_are_hashable(self):
+        for key1, key2 in self.keys_loaded_twice():
+            assert hash(key1) == hash(key2)
+
     def test_autodetect_ed25519(self):
         key = load_private_key_file(_support("test_ed25519.key"))
         self.assertIsInstance(key, Ed25519Key)
