@@ -261,6 +261,34 @@ class TestSFTP(object):
             sftp.remove(sftp.FOLDER + '/fish.txt')
             sftp.remove(sftp.FOLDER + '/tertiary.py')
 
+    def test_listdir_iter_open(self, sftp):
+        """
+        open files while iterating over listdir_iter()
+        """
+        sftp.get_channel().settimeout(1.0)
+        opened = []
+        created = set()
+        try:
+            for i in range(60):
+                fname = "file%02d.txt" % i
+                f = sftp.open(sftp.FOLDER + '/' + fname, 'w')
+                f.write("*" * i)
+                f.close()
+                created.add(fname)
+
+            for attr in sftp.listdir_iter(sftp.FOLDER):
+                f = sftp.open(sftp.FOLDER + '/' + attr.filename)
+                opened.append(f)
+                created.remove(attr.filename)
+
+            assert len(created) == 0
+            # no hang and no timeouts == success
+        finally:
+            for f in opened:
+                f.close()
+            for i in range(60):
+                sftp.remove(sftp.FOLDER + "/file%02d.txt" % i)
+
     def test_setstat(self, sftp):
         """
         verify that the setstat functions (chown, chmod, utime, truncate) work.
@@ -693,23 +721,6 @@ class TestSFTP(object):
         finally:
             sftp.remove(target)
 
-    # TODO: this test doesn't actually fail if the regression (removing '%'
-    # expansion to '%%' within sftp.py's def _log()) is removed - stacktraces
-    # appear but they're clearly emitted from subthreads that have no error
-    # handling. No point running it until that is fixed somehow.
-    @pytest.mark.skip("Doesn't prove anything right now")
-    def test_file_with_percent(self, sftp):
-        """
-        verify that we can create a file with a '%' in the filename.
-        ( it needs to be properly escaped by _log() )
-        """
-        f = sftp.open(sftp.FOLDER + '/test%file', 'w')
-        try:
-            assert f.stat().st_size == 0
-        finally:
-            f.close()
-            sftp.remove(sftp.FOLDER + '/test%file')
-
     def test_non_utf8_data(self, sftp):
         """Test write() and read() of non utf8 data"""
         try:
