@@ -720,7 +720,7 @@ class TransportTest(unittest.TestCase):
         class SendThread(threading.Thread):
             def __init__(self, chan, iterations, done_event):
                 threading.Thread.__init__(self, None, None, self.__class__.__name__)
-                self.setDaemon(True)
+                self.daemon = True
                 self.chan = chan
                 self.iterations = iterations
                 self.done_event = done_event
@@ -741,7 +741,7 @@ class TransportTest(unittest.TestCase):
         class ReceiveThread(threading.Thread):
             def __init__(self, chan, done_event):
                 threading.Thread.__init__(self, None, None, self.__class__.__name__)
-                self.setDaemon(True)
+                self.daemon = True
                 self.chan = chan
                 self.done_event = done_event
                 self.watchdog_event = threading.Event()
